Re-exports
pub use genesis::GenesisState;pub use state::BlockWriter;pub use state::LoadedState;pub use state::ProofWriter;pub use state::ScopedBlockNum;pub use state::ScopedBlockRange;pub use state::State;pub use state::StateView;pub use state::StateWitnesses;pub use state::WriterTask;
Modules
- allowlist
- Stores account registrations and invitation codes for the sequencer.
- genesis
- state
- Abstraction to synchronize state modifications.
Structs
- Account
Tree With History - Wraps
AccountTreewith historical query support via reversion overlays. - Account
Vault Value - Describes the value of an asset for an account ID at
block_numspecifically. - Block
Store - Data
Directory - Represents the store’s data-directory and its content paths.
- Database
Options - Database options used by the store state.
- Db
- The Store’s database.
- Note
Record - Note
Sync Record - Note
Sync Update - Nullifier
Info - Range
Beyond Tip - A requested block range extends beyond the chain tip of the state view serving the request.
- Storage
MapValues Page - Transaction
Record
Enums
- Account
State Forest Update Error - Errors produced while preparing or rebuilding account-state forest updates.
- Apply
Block Error - Apply
Block With Proving Inputs Error - Database
Error - GetAccount
Error - GetBlock
Header Error - GetBlock
Inclusion Proofs Error - GetNote
Inclusion Proofs Error - Historical
Error - Note
Sync Error - State
Sync Error
Traits
- SqlType
Convert - Convert from and to it’s database representation and back
Functions
- default_
sqlite_ connection_ pool_ size - Returns the default number of SQLite connections used by store database pools.
- version
- Returns the store crate version.
Type Aliases
- InMemory
Account Tree - Convenience for an in-memory-only account tree.
- Persistent
Account Tree - Convenience for a persistent account tree.