Module genesis

Module genesis 

Modules

config
Describe a subset of the genesis manifest in easily human readable format

Structs

GenesisBlock
A type-safety wrapper ensuring that genesis block data can only be created from GenesisState or validated from a SignedBlock via GenesisBlock::try_from.
GenesisState
Represents the state at genesis, which will be used to derive the genesis block.
UnsignedGenesisBlock
A genesis block with all data except the validator signature.