pub struct TokenSymbolStr { /* private fields */ }Expand description
Wrapper type used for configuration representation.
Required since Felt does not implement Hash or Eq, but both are useful and necessary for a
coherent model construction.