Module state

Module state 

Abstraction to synchronize state modifications.

The State provides data access and modifications methods, its main purpose is to ensure that data is atomically written, and that reads are consistent.

Structs

BlockNotification
A committed block notification stored in the BlockCache.
BlockWriter
The store’s block-write capability.
LoadedState
A loaded store state whose write worker has not been started yet.
ProofNotification
A proven block notification stored in the ProofCache.
ProofWriter
The store’s proof-write capability.
ScopedBlockNum
A block number proven to be at or below the issuing view’s chain tip.
ScopedBlockRange
A block range whose upper bound is proven to be at or below the issuing view’s chain tip.
State
The rollup state, read-only.
StateView
A consistent read view of the store, pinned at its snapshot’s block height.
StateWitnesses
State witnesses for the requested accounts and nullifiers.
TransactionInputs
Store-level inputs for validating a proven transaction.
WriterTask
Handle of the store’s write worker task, returned by LoadedState::start.

Type Aliases

BlockCache
FIFO cache of recent committed blocks for replica subscriptions.
ProofCache
FIFO cache of recent block proofs for replica subscriptions.