Modules
- config
- Describe a subset of the genesis manifest in easily human readable format
Structs
- Genesis
Block - A type-safety wrapper ensuring that genesis block data can only be created from
GenesisStateor validated from aSignedBlockviaGenesisBlock::try_from. - Genesis
State - Represents the state at genesis, which will be used to derive the genesis block.
- Unsigned
Genesis Block - A genesis block with all data except the validator signature.