Module state

Module state 

Abstraction to synchronize state modifications.

The State provides data access and modifications methods, its main purpose is to ensure that data is atomically written, and that reads are consistent.

Structs

BlockNotification
A committed block notification stored in the BlockCache.
BlockSubscriptionEvent
ProofNotification
A proven block notification stored in the ProofCache.
ProofSubscriptionEvent
State
The rollup state.
TransactionInputs

Enums

Finality
The finality level for chain tip queries.
StateSubscriptionError

Type Aliases

BlockCache
FIFO cache of recent committed blocks for replica subscriptions.
BlockSubscriptionStream
ProofCache
FIFO cache of recent block proofs for replica subscriptions.
ProofSubscriptionStream